@@ -209,6 +209,33 @@ class ApiTest(unittest.TestCase):
         self.assertEqual(get_param(mocker, 'context'), True)
         self.assertEqual(get_param(mocker, 'tags'), True)
 
+    @patch('urllib3.request.RequestMethods.request')
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test06b_resources_by_asset_id(self, mocker):
+        """ should allow listing resources by public ids """
+        mocker.return_value = MOCK_RESPONSE
+        api.resources_by_asset_ids([API_TEST_ID], context=True, tags=True)
+        args, kargs = mocker.call_args
+        self.assertTrue(get_uri(args).endswith('/resources/by_asset_ids'), get_uri(args))
+        self.assertIn(API_TEST_ID, get_list_param(mocker, 'asset_ids'))
+        self.assertEqual(get_param(mocker, 'context'), True)
+        self.assertEqual(get_param(mocker, 'tags'), True)
+        self.assertEqual(get_list_param(mocker, 'asset_ids').__len__(), 1)
+
+    @patch('urllib3.request.RequestMethods.request')
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test06c_resources_by_asset_ids(self, mocker):
+        """ should allow listing resources by public ids """
+        mocker.return_value = MOCK_RESPONSE
+        api.resources_by_asset_ids([API_TEST_ID, API_TEST_ID2], context=True, tags=True)
+        args, kargs = mocker.call_args
+        self.assertTrue(get_uri(args).endswith('/resources/by_asset_ids'), get_uri(args))
+        self.assertIn(API_TEST_ID, get_list_param(mocker, 'asset_ids'))
+        self.assertIn(API_TEST_ID2, get_list_param(mocker, 'asset_ids'))
+        self.assertEqual(get_param(mocker, 'context'), True)
+        self.assertEqual(get_param(mocker, 'tags'), True)
+        self.assertEqual(get_list_param(mocker, 'asset_ids').__len__(), 2)
+
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test_resources_by_context(self):
         """ should allow listing resources by context"""
@@ -246,6 +273,29 @@ class ApiTest(unittest.TestCase):
         self.assertEqual(resource["bytes"], 3381)
         self.assertEqual(len(resource["derived"]), 1, "{} should have one derived resource.".format(API_TEST_ID))
 
+    @patch('urllib3.request.RequestMethods.request')
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test07_a_resource_by_asset_id(self, mocker):
+        mocker.return_value = MOCK_RESPONSE
+        api.resource_by_asset_id(API_TEST_ID, quality_analysis=True , colors=True ,accessibility_analysis=True)
+        args, kargs = mocker.call_args
+        self.assertTrue(get_uri(args).endswith('/resources/{}'.format(API_TEST_ID)))
+        self.assertTrue(get_params(args)['quality_analysis'])
+        self.assertTrue(get_params(args)['colors'])
+        self.assertTrue(get_params(args)['accessibility_analysis'])
+
+
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test07_b_resource_by_asset_id(self):
+        # should allow get resource by asset_id
+        asset_id = api.resource(API_TEST_ID)["asset_id"]
+        resource = api.resource_by_asset_id(asset_id)
+        self.assertNotEqual(resource, None)
+        self.assertEqual(resource["asset_id"], asset_id)
+        self.assertEqual(resource["public_id"], API_TEST_ID)
+        self.assertEqual(resource["bytes"], 3381)
+        self.assertEqual(len(resource["derived"]), 1, "{} should have one derived resource.".format(API_TEST_ID))
+
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test07a_resource_quality_analysis(self):
         """ should allow getting resource quality analysis """
